"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processRawLighthouseResult = exports.processParameters = exports.metricsToSvg = exports.htmlReportsToFile = exports.calculateLighthouseMetrics = void 0;
var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));
var _path = _interopRequireDefault(require("path"));
var _fs = _interopRequireDefault(require("fs"));
var _badgeMaker = require("badge-maker");
var R = _interopRequireWildcard(require("ramda"));
var ChromeLauncher = _interopRequireWildcard(require("chrome-launcher"));
var _index = _interopRequireDefault(require("lighthouse/core/index.cjs"));
var _util = require("./util");
var _calculations = require("./calculations");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { "default": e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n["default"] = e, t && t.set(e, n), n; }
var metricsToSvg = exports.metricsToSvg = /*#__PURE__*/function () {
  var _ref = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee(lighthouseMetrics, badgeStyle, outputPath) {
    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          R.keys(lighthouseMetrics).map(function (lighthouseMetricKey) {
            var filepath = _path["default"].join(outputPath, "".concat(lighthouseMetricKey.replace(/ /g, '_'), ".svg"));
            var badgeColor = (0, _calculations.percentageToColor)(lighthouseMetrics[lighthouseMetricKey]);
            var svg = (0, _badgeMaker.makeBadge)({
              label: lighthouseMetricKey,
              message: "".concat(lighthouseMetrics[lighthouseMetricKey], "%"),
              color: badgeColor,
              style: badgeStyle
            });
            _fs["default"].writeFile(filepath, svg, function (error) {
              return (0, _util.statusMessage)("Saved svg to ".concat(filepath, "\n"), "Failed to save svg to ".concat(outputPath), error);
            });
            return true;
          });
        case 1:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return function metricsToSvg(_x, _x2, _x3) {
    return _ref.apply(this, arguments);
  };
}();
var htmlReportsToFile = exports.htmlReportsToFile = /*#__PURE__*/function () {
  var _ref2 = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee2(htmlReports, outputPath) {
    return _regenerator["default"].wrap(function _callee2$(_context2) {
      while (1) switch (_context2.prev = _context2.next) {
        case 0:
          return _context2.abrupt("return", htmlReports.map(function (report) {
            var url = R.head(R.keys(report));
            if (report[url]) {
              var filepath = _path["default"].join(outputPath, "".concat((0, _util.urlEscaper)(url), ".html"));
              _fs["default"].writeFile(filepath, report[url], function (error) {
                return (0, _util.statusMessage)("Saved report to ".concat(filepath, "\n"), "Failed to save report to ".concat(outputPath), error);
              });
            }
            return false;
          }));
        case 1:
        case "end":
          return _context2.stop();
      }
    }, _callee2);
  }));
  return function htmlReportsToFile(_x4, _x5) {
    return _ref2.apply(this, arguments);
  };
}();
var generateArtifacts = /*#__PURE__*/function () {
  var _ref4 = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee3(_ref3) {
    var reports, svg, outputPath;
    return _regenerator["default"].wrap(function _callee3$(_context3) {
      while (1) switch (_context3.prev = _context3.next) {
        case 0:
          reports = _ref3.reports, svg = _ref3.svg, outputPath = _ref3.outputPath;
          _context3.next = 3;
          return Promise.all([htmlReportsToFile(reports, outputPath), metricsToSvg(svg.results, svg.style, outputPath)]);
        case 3:
        case "end":
          return _context3.stop();
      }
    }, _callee3);
  }));
  return function generateArtifacts(_x6) {
    return _ref4.apply(this, arguments);
  };
}();
var processRawLighthouseResult = exports.processRawLighthouseResult = /*#__PURE__*/function () {
  var _ref5 = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee4(data, html, url, shouldSaveReport) {
    var htmlReport, categories, scores, lighthouseMetrics;
    return _regenerator["default"].wrap(function _callee4$(_context4) {
      while (1) switch (_context4.prev = _context4.next) {
        case 0:
          htmlReport = shouldSaveReport ? html : false;
          categories = data.categories;
          scores = R.keys(categories).map(function (category) {
            return (0, _defineProperty2["default"])({}, "lighthouse ".concat(category.toLowerCase()), categories[category].score * 100);
          });
          lighthouseMetrics = Object.assign.apply(Object, [{}].concat((0, _toConsumableArray2["default"])(scores)));
          return _context4.abrupt("return", {
            metrics: lighthouseMetrics,
            report: (0, _defineProperty2["default"])({}, url, htmlReport)
          });
        case 5:
        case "end":
          return _context4.stop();
      }
    }, _callee4);
  }));
  return function processRawLighthouseResult(_x7, _x8, _x9, _x10) {
    return _ref5.apply(this, arguments);
  };
}();
var calculateLighthouseMetrics = exports.calculateLighthouseMetrics = /*#__PURE__*/function () {
  var _ref7 = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee5(url, shouldSaveReport) {
    var lighthouseParameters,
      chromeParameters,
      chrome,
      options,
      runnerResult,
      reportHtml,
      reportJson,
      _args5 = arguments;
    return _regenerator["default"].wrap(function _callee5$(_context5) {
      while (1) switch (_context5.prev = _context5.next) {
        case 0:
          lighthouseParameters = _args5.length > 2 && _args5[2] !== undefined ? _args5[2] : {};
          chromeParameters = ['--headless', '--no-sandbox', '--disable-gpu', '--disable-dev-shm-usage', '--no-default-browser-check', '--no-first-run', '--disable-default-apps'];
          _context5.next = 4;
          return ChromeLauncher.launch({
            chromeFlags: chromeParameters
          });
        case 4:
          chrome = _context5.sent;
          options = {
            logLevel: 'silent',
            output: 'html',
            port: chrome.port
          };
          _context5.next = 8;
          return (0, _index["default"])(url, options, lighthouseParameters);
        case 8:
          runnerResult = _context5.sent;
          reportHtml = runnerResult.report;
          reportJson = runnerResult.lhr;
          _context5.next = 13;
          return chrome.kill();
        case 13:
          return _context5.abrupt("return", processRawLighthouseResult(reportJson, reportHtml, url, shouldSaveReport));
        case 14:
        case "end":
          return _context5.stop();
      }
    }, _callee5);
  }));
  return function calculateLighthouseMetrics(_x11, _x12) {
    return _ref7.apply(this, arguments);
  };
}();
var processParameters = exports.processParameters = /*#__PURE__*/function () {
  var _ref8 = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee6(parserArgs, func) {
    var lighthouseParameters,
      outputPath,
      results,
      metrics,
      reports,
      metricsResults,
      _args6 = arguments;
    return _regenerator["default"].wrap(function _callee6$(_context6) {
      while (1) switch (_context6.prev = _context6.next) {
        case 0:
          lighthouseParameters = _args6.length > 2 && _args6[2] !== undefined ? _args6[2] : {};
          outputPath = parserArgs.output_path || process.cwd();
          _fs["default"].mkdir(outputPath, {
            recursive: true
          }, function (err) {
            if (err) throw err;
          });
          _context6.next = 5;
          return Promise.all([parserArgs.url].map(function (url) {
            return func(url, parserArgs.save_report, lighthouseParameters);
          }));
        case 5:
          results = _context6.sent;
          metrics = R.pluck('metrics', results);
          reports = R.pluck('report', results);
          if (!parserArgs.single_badge) {
            _context6.next = 14;
            break;
          }
          _context6.next = 11;
          return (0, _calculations.getSquashedScore)(metrics);
        case 11:
          _context6.t0 = _context6.sent;
          _context6.next = 17;
          break;
        case 14:
          _context6.next = 16;
          return (0, _calculations.getAverageScore)(metrics);
        case 16:
          _context6.t0 = _context6.sent;
        case 17:
          metricsResults = _context6.t0;
          _context6.next = 20;
          return generateArtifacts({
            reports: reports,
            svg: {
              results: metricsResults,
              style: parserArgs.badge_style
            },
            outputPath: outputPath
          });
        case 20:
        case "end":
          return _context6.stop();
      }
    }, _callee6);
  }));
  return function processParameters(_x13, _x14) {
    return _ref8.apply(this, arguments);
  };
}();